Assorted spelling fixes

Francois Gouget fgouget at free.fr
Mon Dec 13 06:49:45 CST 2004


Changelog:

  * dlls/avifil32/api.c
    dlls/avifil32/wavfile.c
    dlls/comctl32/comctl32undoc.c
    dlls/dbghelp/mscvpdb.h
    dlls/gdi/enhmfdrv/objects.c
    dlls/kernel/time.c
    dlls/kernel/tests/directory.c
    dlls/mapi32/util.c
    dlls/mscms/profile.c
    dlls/msrle32/msrle32.c
    dlls/ntdll/tests/rtl.c
    dlls/ole32/marshal.c
    dlls/oleaut32/variant.c
    dlls/quartz/filtergraph.c
    dlls/rsaenh/handle.c
    dlls/rsaenh/mpi.c
    dlls/wined3d/device.c
    dlls/winsock/socket.c
    documentation/running.sgml

    Assorted spelling fixes.


-- 
Francois Gouget         fgouget at free.fr        http://fgouget.free.fr/
       Broadcast message : fin du monde dans cinq minutes, repentez vous !
-------------- next part --------------
Index: dlls/avifil32/api.c
===================================================================
RCS file: /var/cvs/wine/dlls/avifil32/api.c,v
retrieving revision 1.29
diff -u -r1.29 api.c
--- dlls/avifil32/api.c	29 Nov 2004 18:00:11 -0000	1.29
+++ dlls/avifil32/api.c	12 Dec 2004 14:11:48 -0000
@@ -251,7 +251,7 @@
   } else
     memcpy(&clsidHandler, lpHandler, sizeof(clsidHandler));
 
-  /* crete instance of handler */
+  /* create instance of handler */
   hr = SHCoCreateInstance(NULL, &clsidHandler, NULL,
 			  &IID_IAVIFile, (LPVOID*)ppfile);
   if (FAILED(hr) || *ppfile == NULL)
@@ -1055,10 +1055,10 @@
   /*
    * 1. iterate over HKEY_CLASSES_ROOT\\AVIFile\\Extensions and collect
    *    extensions and CLSID's
-   * 2. iterate over collected CLSID's and copy it's description and it's
+   * 2. iterate over collected CLSID's and copy its description and its
    *    extensions to szFilter if it fits
    *
-   * First filter is named "All multimedia files" and it's filter is a
+   * First filter is named "All multimedia files" and its filter is a
    * collection of all possible extensions except "*.*".
    */
   if (RegOpenKeyW(HKEY_CLASSES_ROOT, szAVIFileExtensions, &hKey) != S_OK) {
@@ -1315,7 +1315,7 @@
   if (size > 0) {
     szFormat[0] = 0;
 
-    /* read format to build format descriotion string */
+    /* read format to build format description string */
     lpFormat = GlobalAllocPtr(GHND, size);
     if (lpFormat != NULL) {
       if (SUCCEEDED(AVIStreamReadFormat(SaveOpts.ppavis[SaveOpts.nCurrent],sInfo.dwStart,lpFormat, &size))) {
@@ -1478,7 +1478,7 @@
   if (nStreams <= 0 || ppavi == NULL || ppOptions == NULL)
     return AVIERR_BADPARAM;
 
-  /* save options for case user press cancel */
+  /* save options in case the user presses cancel */
   if (ppOptions != NULL && nStreams > 1) {
     pSavedOptions = GlobalAllocPtr(GHND,nStreams * sizeof(AVICOMPRESSOPTIONS));
     if (pSavedOptions == NULL)
@@ -1717,7 +1717,7 @@
     lFirstVideo = 0;
   }
 
-  /* allocate buffer for formats, data, etc. of an initiale size of 64 kByte */
+  /* allocate buffer for formats, data, etc. of an initial size of 64 kBytes*/
   lpBuffer = GlobalAllocPtr(GPTR, cbBuffer = 0x00010000);
   if (lpBuffer == NULL) {
     hres = AVIERR_MEMORY;
@@ -1729,7 +1729,7 @@
   dwFileInitialFrames = 0;
   if (lFirstVideo >= 0) {
     /* check for correct version of the format
-     *  -- need atleast BITMAPINFOHEADER or newer
+     *  -- need at least BITMAPINFOHEADER or newer
      */
     lSampleInc = 1;
     lBufferSize = cbBuffer;
@@ -1846,7 +1846,7 @@
 	while (lFirstVideo > lStart[curStream]) {
 	  DWORD flags = 0;
 
-	  /* copy format for case it can change */
+	  /* copy format in case it can change */
 	  lBufferSize = cbBuffer;
 	  hres = AVIStreamReadFormat(pInStreams[curStream], lStart[curStream],
 				     lpBuffer, &lBufferSize);
@@ -1910,7 +1910,7 @@
 	while (sInfo.dwStart < sInfo.dwLength) {
 	  LONG lSamples = cbBuffer / sInfo.dwSampleSize;
 
-	  /* copy format for case it can change */
+	  /* copy format in case it can change */
 	  lBufferSize = cbBuffer;
 	  hres = AVIStreamReadFormat(pInStreams[curStream], sInfo.dwStart,
 				     lpBuffer, &lBufferSize);
@@ -1923,7 +1923,7 @@
 	  if (lSamples != (LONG)(sInfo.dwLength - sInfo.dwStart))
 	    lSamples = sInfo.dwLength - sInfo.dwStart;
 
-	  /* now try to read until we got it, or error occures */
+	  /* now try to read until we get it, or an error occurs */
 	  do {
 	    lReadBytes   = cbBuffer;
 	    lReadSamples = 0;
@@ -1960,7 +1960,7 @@
 	for (; sInfo.dwStart < sInfo.dwLength; sInfo.dwStart++) {
 	  DWORD flags = 0;
 
-	  /* copy format for case it can change */
+	  /* copy format in case it can change */
 	  lBufferSize = cbBuffer;
 	  hres = AVIStreamReadFormat(pInStreams[curStream], sInfo.dwStart,
 				     lpBuffer, &lBufferSize);
Index: dlls/avifil32/wavfile.c
===================================================================
RCS file: /var/cvs/wine/dlls/avifil32/wavfile.c,v
retrieving revision 1.15
diff -u -r1.15 wavfile.c
--- dlls/avifil32/wavfile.c	5 Oct 2004 18:10:21 -0000	1.15
+++ dlls/avifil32/wavfile.c	12 Dec 2004 14:14:46 -0000
@@ -475,7 +475,7 @@
   if (lParam < 0)
     return AVIERR_BADPARAM;
 
-  /* Have we our audio stream? */
+  /* Do we have our audio stream? */
   if (lParam != 0 || This->fInfo.dwStreams == 0 ||
       (fccType != 0 && fccType != streamtypeAUDIO))
     return AVIERR_NODATA;
@@ -886,7 +886,7 @@
 
   /* request only the sizes? */
   if (buffer == NULL || buffersize <= 0) {
-    /* then I need atleast one parameter for it */
+    /* then I need at least one parameter for it */
     if (bytesread == NULL && samplesread == NULL)
       return AVIERR_BADPARAM;
 
@@ -902,7 +902,7 @@
   if (samples == 0)
     return AVIERR_OK;
 
-  /* Can I atleast read one sample? */
+  /* Can I read at least one sample? */
   if ((DWORD)buffersize < This->sInfo.dwSampleSize)
     return AVIERR_BUFFERTOOSMALL;
 
@@ -944,7 +944,7 @@
   if (buffer == NULL && (buffersize > 0 || samples > 0))
     return AVIERR_BADPARAM;
 
-  /* Have we write permission? */
+  /* Do we have write permission? */
   if ((This->uMode & MMIO_RWMODE) == 0)
     return AVIERR_READONLY;
 
@@ -956,7 +956,7 @@
   if (buffersize & ~(This->sInfo.dwSampleSize - 1))
     return AVIERR_BADSIZE;
 
-  /* have we anything to write? */
+  /* do we have anything to write? */
   if (buffer != NULL && buffersize > 0) {
     This->fDirty = 1;
 
@@ -1296,7 +1296,7 @@
       dwFactLength /= wfx.nBlockAlign;
       acmStreamClose(has, 0);
 
-      /* crete the fact chunk */
+      /* create the fact chunk */
       ck.ckid   = ckidWAVEFACT;
       ck.cksize = sizeof(dwFactLength);
 
@@ -1314,7 +1314,7 @@
       ERR(": fact chunk is needed for non-pcm files -- currently no codec found, so skipped!\n");
   }
 
-  /* if here was extra stuff, we need to fill it with JUNK */
+  /* if there was extra stuff, we need to fill it with JUNK */
   if (mmioSeek(This->hmmio, 0, SEEK_CUR) + 2 * sizeof(DWORD) < This->ckData.dwDataOffset) {
     ck.ckid   = ckidAVIPADDING;
     ck.cksize = 0;
@@ -1328,7 +1328,7 @@
       return AVIERR_FILEWRITE;
   }
 
-  /* crete the data chunk */
+  /* create the data chunk */
   ck.ckid   = ckidWAVEDATA;
   ck.cksize = This->ckData.cksize;
   if (mmioCreateChunk(This->hmmio, &ck, 0) != S_OK)
Index: dlls/comctl32/comctl32undoc.c
===================================================================
RCS file: /var/cvs/wine/dlls/comctl32/comctl32undoc.c,v
retrieving revision 1.95
diff -u -r1.95 comctl32undoc.c
--- dlls/comctl32/comctl32undoc.c	10 Dec 2004 15:31:38 -0000	1.95
+++ dlls/comctl32/comctl32undoc.c	12 Dec 2004 13:21:18 -0000
@@ -496,7 +496,7 @@
  *                  This must be supplied by the caller.
  *  lpszSubKey  [I] A caller supplied name of a subkey under hKey to write
  *                  the list to. This may not be blank.
- *  lpfnCompare [I] A caller supplied comparason function, which may be either
+ *  lpfnCompare [I] A caller supplied comparison function, which may be either
  *                  an MRUStringCmpFn if dwFlags does not have bit 0 set, or a
  *                  MRUBinaryCmpFn otherwise.
  *
Index: dlls/dbghelp/mscvpdb.h
===================================================================
RCS file: /var/cvs/wine/dlls/dbghelp/mscvpdb.h,v
retrieving revision 1.1
diff -u -r1.1 mscvpdb.h
--- dlls/dbghelp/mscvpdb.h	21 Nov 2004 15:51:47 -0000	1.1
+++ dlls/dbghelp/mscvpdb.h	26 Nov 2004 00:55:16 -0000
@@ -93,7 +93,7 @@
  * -----------------------
  * Here also we find three flavors (that we've suffixed with _V1, _V2
  * and _V3) even if their evolution is closer to the evolution of
- * types, there are not completly linked together.
+ * types, they are not completely linked together.
  */
 
 #include "pshpack1.h"
Index: dlls/gdi/enhmfdrv/objects.c
===================================================================
RCS file: /var/cvs/wine/dlls/gdi/enhmfdrv/objects.c,v
retrieving revision 1.12
diff -u -r1.12 objects.c
--- dlls/gdi/enhmfdrv/objects.c	22 Nov 2004 18:22:20 -0000	1.12
+++ dlls/gdi/enhmfdrv/objects.c	26 Nov 2004 00:56:11 -0000
@@ -235,14 +235,14 @@
                       bm.bmHeight * BITMAP_GetWidthBytes(bm.bmWidth, bm.bmBitsPixel),
                       (LPBYTE)info + sizeof(BITMAPINFOHEADER));
 
-        /* Change the padding to DIB compatable if needed */
+        /* Change the padding to be DIB compatible if needed */
         if (bm.bmWidth & 31)
             EMFDRV_PadTo32((LPBYTE)info + sizeof(BITMAPINFOHEADER), bm.bmWidth, bm.bmHeight);
 
         emr->emr.iType = EMR_CREATEMONOBRUSH;
         emr->emr.nSize = size;
         emr->ihBrush = index = EMFDRV_AddHandle( dev, hBrush );
-        /* Presumably to reduce the size of the written EMF, MS support an
+        /* Presumably to reduce the size of the written EMF, MS supports an
          * undocumented iUsage value of 2, indicating a mono bitmap without the
          * 8 byte 2 entry black/white palette. Stupidly, they could have saved
          * over 20 bytes more by also ignoring the BITMAPINFO fields that are
Index: dlls/kernel/time.c
===================================================================
RCS file: /var/cvs/wine/dlls/kernel/time.c,v
retrieving revision 1.46
diff -u -r1.46 time.c
--- dlls/kernel/time.c	6 Nov 2004 03:53:53 -0000	1.46
+++ dlls/kernel/time.c	12 Dec 2004 14:18:25 -0000
@@ -81,7 +81,7 @@
  *  -1 if date < compareDate
  *   0 if date == compareDate
  *   1 if date > compareDate
- *  -2 if an error occures
+ *  -2 if an error occurs
  */
 static int TIME_DayLightCompareDate(
     const SYSTEMTIME *date,        /* [in] The local time to compare. */
Index: dlls/kernel/tests/directory.c
===================================================================
RCS file: /var/cvs/wine/dlls/kernel/tests/directory.c,v
retrieving revision 1.13
diff -u -r1.13 directory.c
--- dlls/kernel/tests/directory.c	29 Nov 2004 17:52:06 -0000	1.13
+++ dlls/kernel/tests/directory.c	6 Dec 2004 22:40:34 -0000
@@ -213,7 +213,7 @@
     lstrcatA(tmpdir, "Please Remove Me/Please Remove Me");
     ret = CreateDirectoryA(tmpdir, NULL);
     ok(ret == FALSE && GetLastError() == ERROR_PATH_NOT_FOUND, 
-      "CreateDirectoryA with multiple non existing directories in path should fail\n");
+      "CreateDirectoryA with multiple non-existent directories in path should fail\n");
     ret = RemoveDirectoryA(tmpdir);
     
 }
@@ -285,7 +285,7 @@
     lstrcatW(tmpdir, tmp_dir_name);
     ret = CreateDirectoryW(tmpdir, NULL);
     ok(ret == FALSE && GetLastError() == ERROR_PATH_NOT_FOUND, 
-      "CreateDirectoryW with multiple non existing directories in path should fail\n");
+      "CreateDirectoryW with multiple non-existent directories in path should fail\n");
     ret = RemoveDirectoryW(tmpdir);
 }
 
Index: dlls/mapi32/util.c
===================================================================
RCS file: /var/cvs/wine/dlls/mapi32/util.c,v
retrieving revision 1.6
diff -u -r1.6 util.c
--- dlls/mapi32/util.c	30 Nov 2004 17:38:52 -0000	1.6
+++ dlls/mapi32/util.c	6 Dec 2004 22:45:11 -0000
@@ -718,7 +718,7 @@
  * Read an integer from a hexadecimal string.
  *
  * PARAMS
- *  lpSzHex [I] String containing the hexidecimal number to read
+ *  lpSzHex [I] String containing the hexadecimal number to read
  *
  * RETURNS
  * Success: The number represented by lpszHex.
Index: dlls/mscms/profile.c
===================================================================
RCS file: /var/cvs/wine/dlls/mscms/profile.c,v
retrieving revision 1.8
diff -u -r1.8 profile.c
--- dlls/mscms/profile.c	7 Dec 2004 14:42:47 -0000	1.8
+++ dlls/mscms/profile.c	7 Dec 2004 14:51:46 -0000
@@ -103,7 +103,7 @@
  * PARAMS
  *  machine  [I]   Name of the machine for which to get the color directory.
  *                 Must be NULL, which indicates the local machine.
- *  buffer   [I]   Buffer to recieve the path name in.
+ *  buffer   [I]   Buffer to receive the path name in.
  *  size     [I/O] Size of the buffer in bytes. On return the variable holds
  *                 the number of bytes actually needed.
  */
Index: dlls/msrle32/msrle32.c
===================================================================
RCS file: /var/cvs/wine/dlls/msrle32/msrle32.c,v
retrieving revision 1.9
diff -u -r1.9 msrle32.c
--- dlls/msrle32/msrle32.c	16 Jul 2004 23:20:38 -0000	1.9
+++ dlls/msrle32/msrle32.c	12 Dec 2004 14:17:51 -0000
@@ -295,12 +295,12 @@
     clr4 = lpB[++pos];
     if (ColorCmp(clr1, clr3) <= lDist &&
 	ColorCmp(clr2, clr4) <= lDist) {
-      /* diff at end? -- look-ahead for atleast ?? more encodable pixel */
+      /* diff at end? -- look-ahead for at least ?? more encodable pixels */
       if (pos + 2 < width && ColorCmp(clr1,lpB[pos+1]) <= lDist &&
 	  ColorCmp(clr2,lpB[pos+2]) <= lDist) {
 	if (pos + 4 < width && ColorCmp(lpB[pos+1],lpB[pos+3]) <= lDist &&
 	    ColorCmp(lpB[pos+2],lpB[pos+4]) <= lDist)
-	  return count - 3; /* followed by atleast 4 encodable pixels */
+	  return count - 3; /* followed by at least 4 encodable pixels */
 	return count - 2;
       }
     } else if (lpP != NULL && ColorCmp(lpP[pos], lpB[pos]) <= lDist) {
@@ -392,7 +392,7 @@
     if (x + count > lpbi->biWidth)
       count = lpbi->biWidth - x;
 
-    /* absolute pixel(s) in groups of atleast 3 and maximal 254 pixel */
+    /* absolute pixel(s) in groups of at least 3 and at most 254 pixels */
     while (count > 2) {
       INT  i;
       INT  size       = min(count, 254);
@@ -420,7 +420,7 @@
     }
 
     if (count > 0) {
-      /* too less for absoluting so we must encode them */
+      /* too little for absoluting so we must encode them */
       assert(count <= 2);
 
       *lpSizeImage += 2;
@@ -482,7 +482,7 @@
     if (x + count > lpbi->biWidth)
       count = lpbi->biWidth - x;
 
-    /* absolute pixel(s) in groups of atleast 3 and maximal 255 pixels */
+    /* absolute pixel(s) in groups of at least 3 and at most 255 pixels */
     while (count > 2) {
       INT  i;
       INT  size       = min(count, 255);
@@ -500,7 +500,7 @@
 	*lpOut++ = 0;
     }
     if (count > 0) {
-      /* too less for absoluting so we must encode them even if it's expensive! */
+      /* too little for absoluting so we must encode them even if it's expensive! */
       assert(count <= 2);
 
       *lpSizeImage += 2 * count;
@@ -1238,7 +1238,7 @@
   /* pre-condition */
   assert(pi != NULL);
 
-  /* check parameters -- need atleast input format */
+  /* check parameters -- need at least input format */
   if (lpbiIn == NULL) {
     if (lpbiOut != NULL)
       return ICERR_BADPARAM;
@@ -1310,7 +1310,7 @@
 
   TRACE("(%p,%p,%p)\n",pi,lpbiIn,lpbiOut);
 
-  /* check parameter -- need atleast one format */
+  /* check parameter -- need at least one format */
   if (lpbiIn == NULL && lpbiOut == NULL)
     return 0;
   /* check if the given format is supported */
@@ -1330,7 +1330,7 @@
   /* pre-condition */
   assert(pi != NULL);
 
-  /* need atleast one format */
+  /* need at least one format */
   if (lpbiIn == NULL && lpbiOut == NULL)
     return ICERR_BADPARAM;
 
@@ -1597,7 +1597,7 @@
   /* pre-condition */
   assert(pi != NULL);
 
-  /* need atleast one format */
+  /* need at least one format */
   if (lpbiIn == NULL && lpbiOut == NULL)
     return ICERR_BADPARAM;
 
Index: dlls/ntdll/tests/rtl.c
===================================================================
RCS file: /var/cvs/wine/dlls/ntdll/tests/rtl.c,v
retrieving revision 1.11
diff -u -r1.11 rtl.c
--- dlls/ntdll/tests/rtl.c	7 Dec 2004 14:47:13 -0000	1.11
+++ dlls/ntdll/tests/rtl.c	12 Dec 2004 22:38:37 -0000
@@ -654,7 +654,7 @@
  * seed = 0;
  * RtlRandom(&seed);
  *
- * assigns to seed. Putting this two findings together leads to
+ * assigns to seed. Putting these two findings together leads to
  * the concluson that RtlRandom saves the value in some variable,
  * like in the following algorithm:
  *
@@ -685,13 +685,13 @@
  * RtlUniform(&seed);
  * return(result);
  *
- * But how the value of pos is determined? The calls to RtlUniform
+ * But how is the value of pos determined? The calls to RtlUniform
  * create a sequence of random numbers. Every second random number
  * is put into the saved_value array and is used in some later call
  * of RtlRandom as result. The only reasonable source to determine
  * pos are the random numbers generated by RtlUniform which are not
  * put into the saved_value array. This are the values of seed
- * between the two calls of RtlUniform as in this altorithm:
+ * between the two calls of RtlUniform as in this algorithm:
  *
  * rand = RtlUniform(&seed);
  * RtlUniform(&seed);
@@ -700,10 +700,10 @@
  * saved_value[pos] = rand;
  * return(result);
  *
- * What remains to determine is: The size of the saved_value array,
+ * What remains to be determined is: The size of the saved_value array,
  * the initial values of the saved_value array and the function
- * position(seed). This tests are not shown here. 
- * The result of this tests ist: The size of the saved_value array
+ * position(seed). These tests are not shown here. 
+ * The result of these tests is: The size of the saved_value array
  * is 128, the initial values can be seen in the my_RtlRandom
  * function and the position(seed) function is (seed & 0x7f).
  *
Index: dlls/ole32/marshal.c
===================================================================
RCS file: /var/cvs/wine/dlls/ole32/marshal.c,v
retrieving revision 1.36
diff -u -r1.36 marshal.c
--- dlls/ole32/marshal.c	8 Dec 2004 17:49:30 -0000	1.36
+++ dlls/ole32/marshal.c	8 Dec 2004 19:31:39 -0000
@@ -782,8 +782,8 @@
  * Marshals an HRESULT value into a stream.
  *
  * PARAMS
- *  pStm    [I] Stream that hresult will be marshaled into.
- *  hresult [I] HRESULT to be marshaled.
+ *  pStm    [I] Stream that hresult will be marshalled into.
+ *  hresult [I] HRESULT to be marshalled.
  *
  * RETURNS
  *  Success: S_OK
@@ -804,8 +804,8 @@
  * Unmarshals an HRESULT value from a stream.
  *
  * PARAMS
- *  pStm     [I] Stream that hresult will be unmarshaled from.
- *  phresult [I] Pointer to HRESULT where the value will be unmarshaled to.
+ *  pStm     [I] Stream that hresult will be unmarshalled from.
+ *  phresult [I] Pointer to HRESULT where the value will be unmarshalled to.
  *
  * RETURNS
  *  Success: S_OK
Index: dlls/oleaut32/variant.c
===================================================================
RCS file: /var/cvs/wine/dlls/oleaut32/variant.c,v
retrieving revision 1.106
diff -u -r1.106 variant.c
--- dlls/oleaut32/variant.c	8 Dec 2004 13:59:52 -0000	1.106
+++ dlls/oleaut32/variant.c	8 Dec 2004 14:45:40 -0000
@@ -3925,7 +3925,7 @@
  *  Failure: An HRESULT error code indicating the error.
  *
  * NOTES
- *  - Strictly speaking, this function performs a bitwise ones compliment
+ *  - Strictly speaking, this function performs a bitwise ones complement
  *    on the variants value (after possibly converting to VT_I4, see below).
  *    This only behaves like a boolean not operation if the value in
  *    pVarIn is either VARIANT_TRUE or VARIANT_FALSE and the type is signed.
Index: dlls/rsaenh/handle.c
===================================================================
RCS file: /var/cvs/wine/dlls/rsaenh/handle.c,v
retrieving revision 1.1
diff -u -r1.1 handle.c
--- dlls/rsaenh/handle.c	4 Nov 2004 21:15:32 -0000	1.1
+++ dlls/rsaenh/handle.c	26 Nov 2004 00:54:01 -0000
@@ -131,8 +131,8 @@
  *  lplpTable [O] Pointer to the variable, to which the pointer to the newly
  *                allocated handle table is written.
  * RETURNS
- *  non zero,  if successfull
- *  zero,      if not successfull (out of process heap memory)
+ *  non zero,  if successful
+ *  zero,      if not successful (out of process heap memory)
  *
  * NOTES
  *  If all you need is a single handle table, you may as well declare a global 
@@ -155,14 +155,14 @@
 /******************************************************************************
  *  release_handle_table
  *
- * Releases a handle table and frees the resources occupied by it.
+ * Releases a handle table and frees the resources it used.
  *
  * PARAMS
  *  lpTable [I] Pointer to the handle table, which is to be released.
  *
  * RETURNS
- *  non zero,  if successfull
- *  zero,      if not successfull
+ *  non zero,  if successful
+ *  zero,      if not successful
  *
  * NOTES
  *   All valid handles still in the table are released also.
@@ -185,8 +185,8 @@
  *  lpTable [I] Pointer to the table, which is to be grown
  *
  * RETURNS
- *  non zero,  if successfull
- *  zero,      if not successfull (out of memory on process heap)
+ *  non zero,  if successful
+ *  zero,      if not successful (out of memory on process heap)
  *
  * NOTES
  *  This is a support function for alloc_handle. Do not call!
@@ -231,11 +231,11 @@
  *               allocated.
  *  lpObject [I] Pointer to the object, for which a handle shall be allocated.
  *  lpHandle [O] Pointer to a handle variable, into which the handle value will
- *               be stored. If not successfull, this will be 
+ *               be stored. If not successful, this will be 
  *               INVALID_HANDLE_VALUE
  * RETURNS
- *  non zero,  if successfull
- *  zero,      if not successfull (no free handle)
+ *  non zero,  if successful
+ *  zero,      if not successful (no free handle)
  */
 int alloc_handle(HANDLETABLE *lpTable, OBJECTHDR *lpObject, unsigned int *lpHandle)
 {
@@ -281,8 +281,8 @@
  *              to be released.
  *
  * RETURNS
- *  non zero,  if successfull
- *  zero,      if not successfull (invalid handle)
+ *  non zero,  if successful
+ *  zero,      if not successful (invalid handle)
  */
 int release_handle(HANDLETABLE *lpTable, unsigned int handle, DWORD dwType)
 {
@@ -346,8 +346,8 @@
  *    lplpObject [O] Pointer to the variable, into which the pointer to the 
  *                   object looked up is copied.
  * RETURNS
- *  non zero,  if successfull
- *  zero,      if not successfull (invalid handle)
+ *  non zero,  if successful
+ *  zero,      if not successful (invalid handle)
  */
 int lookup_handle(HANDLETABLE *lpTable, unsigned int handle, DWORD dwType, OBJECTHDR **lplpObject)
 {
@@ -372,8 +372,8 @@
 /******************************************************************************
  *  copy_handle
  *
- * Copies a handle. Increments reference count in the object referenced by the
- * handle
+ * Copies a handle. Increments the reference count of the object referenced
+ * by the handle.
  *
  * PARAMS
  *  lpTable [I] Pointer to the handle table, which holds the handle to be copied.
@@ -381,8 +381,8 @@
  *  copy    [O] Pointer to a handle variable, where the copied handle is put.
  *
  * RETURNS
- *  non zero,  if successfull
- *  zero,      if not successfull (invalid handle or out of memory)
+ *  non zero,  if successful
+ *  zero,      if not successful (invalid handle or out of memory)
  */
 int copy_handle(HANDLETABLE *lpTable, unsigned int handle, DWORD dwType, unsigned int *copy)
 {
@@ -425,7 +425,7 @@
  *
  * RETURNS
  *  INVALID_HANDLE_VALUE,        if something went wrong.
- *  a handle to the new object,  if successfull. 
+ *  a handle to the new object,  if successful. 
  */
 unsigned int new_object(HANDLETABLE *lpTable, size_t cbSize, DWORD dwType, DESTRUCTOR destructor, 
                         OBJECTHDR **ppObject)
Index: dlls/rsaenh/mpi.c
===================================================================
RCS file: /var/cvs/wine/dlls/rsaenh/mpi.c,v
retrieving revision 1.1
diff -u -r1.1 mpi.c
--- dlls/rsaenh/mpi.c	30 Nov 2004 17:43:59 -0000	1.1
+++ dlls/rsaenh/mpi.c	6 Dec 2004 22:46:51 -0000
@@ -600,7 +600,7 @@
   /* zero a as per default */
   mp_zero (a);
 
-  /* grow a to accomodate the single bit */
+  /* grow a to accommodate the single bit */
   if ((res = mp_grow (a, b / DIGIT_BIT + 1)) != MP_OKAY) {
     return res;
   }
@@ -2827,7 +2827,7 @@
 {
   int     x, res, oldused;
 
-  /* grow to accomodate result */
+  /* grow to accommodate result */
   if (b->alloc < a->used + 1) {
     if ((res = mp_grow (b, a->used + 1)) != MP_OKAY) {
       return res;
Index: dlls/wined3d/device.c
===================================================================
RCS file: /var/cvs/wine/dlls/wined3d/device.c,v
retrieving revision 1.11
diff -u -r1.11 device.c
--- dlls/wined3d/device.c	9 Dec 2004 14:07:59 -0000	1.11
+++ dlls/wined3d/device.c	12 Dec 2004 00:07:43 -0000
@@ -407,9 +407,11 @@
     D3DMATRIX *mat = NULL;
     D3DMATRIX temp;
 
-    /* Note: Using 'updateStateBlock' rather then 'stateblock' in the code below
-        means it will be recorded in a state block change, but iworks regardless of recording being on. 
-        If this is found to be wrong, change to StateBlock.                             */
+    /* Note: Using 'updateStateBlock' rather than 'stateblock' in the code
+     * below means it will be recorded in a state block change, but it
+     * works regardless where it is recorded. 
+     * If this is found to be wrong, change to StateBlock.
+     */
     IWineD3DDeviceImpl *This = (IWineD3DDeviceImpl *)iface;
     TRACE("(%p) : For state %u\n", This, State);
 
@@ -451,7 +453,7 @@
  *   WARNING: This code relies on the fact that D3DLIGHT8 == D3DLIGHT9
  *****/
 /* Note lights are real special cases. Although the device caps state only eg. 8 are supported,
-   you can reference any indexes you want as long as that number max are enabled are any
+   you can reference any indexes you want as long as that number max are enabled at any
    one point in time! Therefore since the indexes can be anything, we need a linked list of them.
    However, this causes stateblock problems. When capturing the state block, I duplicate the list,
    but when recording, just build a chain pretty much of commands to be replayed.                  */
@@ -716,12 +718,12 @@
         lightInfo->lightEnabled = FALSE;
     } else {
 
-        /* We are enabling it. If it is enabled, its really simple */
+        /* We are enabling it. If it is enabled, it's really simple */
         if (lightInfo->lightEnabled) {
             /* nop */
             TRACE("Nothing to do as light was enabled\n");
 
-        /* If it already has a glIndex, its still simple */
+        /* If it already has a glIndex, it's still simple */
         } else if (lightInfo->glIndex != -1) {
             TRACE("Reusing light as already set up at gl idx %ld\n", lightInfo->glIndex);
             lightInfo->lightEnabled = TRUE;
@@ -815,7 +817,7 @@
                 lightInfo->glIndex = glIndex;
                 lightInfo->lightEnabled = TRUE;
 
-                /* In an ideal world, its already in the right place */
+                /* In an ideal world, it's already in the right place */
                 if (lightInfo->prev == NULL || lightInfo->prev->glIndex!=-1) {
                    /* No need to move it */
                 } else {
@@ -1179,7 +1181,7 @@
 
     if (This->stateBlock->stream_source[0] != NULL) IWineD3DVertexBuffer_Release(This->stateBlock->stream_source[0]);
 
-    /* Note in the following, its not this type, but thats the purpose of streamIsUP */
+    /* Note in the following, it's not this type, but that's the purpose of streamIsUP */
     This->stateBlock->stream_source[0] = (IWineD3DVertexBuffer *)pVertexStreamZeroData; 
     This->stateBlock->stream_stride[0] = VertexStreamZeroStride;
     This->stateBlock->streamIsUP = TRUE;
@@ -1212,7 +1214,7 @@
         idxStride = 4;
     }
 
-    /* Note in the following, its not this type, but thats the purpose of streamIsUP */
+    /* Note in the following, it's not this type, but that's the purpose of streamIsUP */
     This->stateBlock->stream_source[0] = (IWineD3DVertexBuffer *)pVertexStreamZeroData;
     This->stateBlock->streamIsUP = TRUE;
     This->stateBlock->stream_stride[0] = VertexStreamZeroStride;
Index: dlls/winsock/socket.c
===================================================================
RCS file: /var/cvs/wine/dlls/winsock/socket.c,v
retrieving revision 1.166
diff -u -r1.166 socket.c
--- dlls/winsock/socket.c	6 Dec 2004 16:52:36 -0000	1.166
+++ dlls/winsock/socket.c	12 Dec 2004 14:29:47 -0000
@@ -1006,7 +1006,7 @@
 /***********************************************************************
  *              WS2_recv                (INTERNAL)
  *
- * Work horse for both synchronous and asynchronous recv() operations.
+ * Workhorse for both synchronous and asynchronous recv() operations.
  */
 static int WS2_recv ( int fd, struct iovec* iov, int count,
                       struct WS_sockaddr *lpFrom, LPINT lpFromlen,
@@ -1115,7 +1115,7 @@
 /***********************************************************************
  *              WS2_send                (INTERNAL)
  *
- * Work horse for both synchronous and asynchronous send() operations.
+ * Workhorse for both synchronous and asynchronous send() operations.
  */
 static int WS2_send ( int fd, struct iovec* iov, int count,
                       const struct WS_sockaddr *to, INT tolen, DWORD dwFlags )
@@ -1144,7 +1144,7 @@
             int val=0;
             int len=sizeof(int);
 
-            /* The packet type is stored at the ipx socket level; Atleast the linux kernel seems
+            /* The packet type is stored at the ipx socket level; At least the linux kernel seems
              *  to do something with it in case hdr.msg_name is NULL. Nonetheless can we use it to store
              *  the packet type and then we can retrieve it using getsockopt. After that we can set the
              *  ipx type in the sockaddr_opx structure with the stored value.
@@ -1637,8 +1637,8 @@
 		return 0;
 	    case IPX_ADDRESS:
 		/*
-		*  On a Win2000 system with one network card there are useally three ipx devices one with a speed of 28.8kbps, 10Mbps and 100Mbps.
-		*  Using this call you can then retrieve info about this all. In case of Linux it is a bit different. Useally you have
+		*  On a Win2000 system with one network card there are usually three ipx devices one with a speed of 28.8kbps, 10Mbps and 100Mbps.
+		*  Using this call you can then retrieve info about this all. In case of Linux it is a bit different. Usually you have
 		*  only "one" device active and further it is not possible to query things like the linkspeed.
 		*/
 		FIXME("IPX_ADDRESS\n");
@@ -1652,7 +1652,7 @@
 		data->adapternum = 0;
 		data->wan = FALSE; /* We are not on a wan for now .. */
 		data->status = FALSE; /* Since we are not on a wan, the wan link isn't up */
-		data->maxpkt = 1467; /* This value is the default one on atleast Win2k/WinXP */
+		data->maxpkt = 1467; /* This value is the default one, at least on Win2k/WinXP */
 		data->linkspeed = 100000; /* Set the line speed in 100bit/s to 10 Mbit; note 1MB = 1000kB in this case */
 		return 0;	
 	    case IPX_MAX_ADAPTER_NUM:
@@ -1805,7 +1805,7 @@
  */
 char* WINAPI WS_inet_ntoa(struct WS_in_addr in)
 {
-  /* use "buffer for dummies" here because some applications have
+  /* use "buffer for dummies" here because some applications have a
    * propensity to decode addresses in ws_hostent structure without
    * saving them first...
    */
@@ -2050,7 +2050,7 @@
     case SIOCGIFNETMASK:
     case SIOCGIFADDR:
         /* These don't need any special handling.  They are used by
-           WsControl, and are here to suppress an unecessary warning. */
+           WsControl, and are here to suppress an unnecessary warning. */
         break;
 
     default:
@@ -2397,8 +2397,8 @@
 
     /* For some reason the game GrandPrixLegends does set SO_DONTROUTE on its
      * socket. This will either not happen under windows or it is ignored in
-     * windows (but it works in linux and therefor prevents the game to find
-     * games outsite the current network) */
+     * windows (but it works in linux and therefore prevents the game from
+     * finding games outside the current network) */
     if ( level==WS_SOL_SOCKET && optname==WS_SO_DONTROUTE ) 
     {
         FIXME("Does windows ignore SO_DONTROUTE?\n");
@@ -2972,7 +2972,7 @@
  */
 WSAEVENT WINAPI WSACreateEvent(void)
 {
-    /* Create a manual-reset event, with initial state: unsignealed */
+    /* Create a manual-reset event, with initial state: unsignaled */
     TRACE("\n");
 
     return CreateEventA(NULL, TRUE, FALSE, NULL);
Index: documentation/running.sgml
===================================================================
RCS file: /var/cvs/wine/documentation/running.sgml,v
retrieving revision 1.31
diff -u -r1.31 running.sgml
--- documentation/running.sgml	6 Dec 2004 16:42:33 -0000	1.31
+++ documentation/running.sgml	12 Dec 2004 22:29:55 -0000
@@ -691,7 +691,7 @@
 			  </listitem>
 			  <listitem>
 			    <para>
-			      Win32: this are the standard Windows
+			      Win32: these are the standard Windows
 			      console key-bindings (mainly using
 			      arrows).
 			    </para>


More information about the wine-patches mailing list
Index: dlls/quartz/filtergraph.c
===================================================================
RCS file: /var/cvs/wine/dlls/quartz/filtergraph.c,v
retrieving revision 1.19
diff -u -r1.19 filtergraph.c
--- dlls/quartz/filtergraph.c	6 Dec 2004 11:47:13 -0000	1.19
+++ dlls/quartz/filtergraph.c	6 Dec 2004 18:54:15 -0000
@@ -556,7 +556,7 @@
                 IPin_Release(ppin);
         }
         *pppins = CoTaskMemAlloc(sizeof(IPin*)*i);
         /* Retreive output pins */
         IEnumPins_Reset(penumpins);
         i = 0;
         while(IEnumPins_Next(penumpins, 1, &ppin, &nb) == S_OK) {
@@ -604,7 +604,7 @@
     TRACE("Try direct connection first\n");
     hr = IPin_Connect(ppinOut, ppinIn, NULL);
     if (SUCCEEDED(hr)) {
-        TRACE("Direct connection successfull\n");
+        TRACE("Direct connection successful\n");
         return S_OK;
     }
     TRACE("Direct connection failed, trying to insert other filters\n");
@@ -650,7 +650,7 @@
         hr = GetFilterInfo(pMoniker, &clsid, &var);
         IMoniker_Release(pMoniker);
         if (FAILED(hr)) {
-           ERR("Unable to retreive filter info (%lx)\n", hr);
+           ERR("Unable to retrieve filter info (%lx)\n", hr);
            goto error;
         }
 
@@ -776,7 +776,7 @@
             hr = GetFilterInfo(pMoniker, &clsid, &var);
             IMoniker_Release(pMoniker);
             if (FAILED(hr)) {
-                ERR("Unable to retreive filter info (%lx)\n", hr);
+                ERR("Unable to retrieve filter info (%lx)\n", hr);
                 goto error;
             }
 
@@ -859,7 +859,7 @@
 
     hr = IGraphBuilder_AddSourceFilter(iface, lpcwstrFile, string, &preader);
 
     /* Retreive file media type */
     if (SUCCEEDED(hr))
         hr = IBaseFilter_QueryInterface(preader, &IID_IFileSourceFilter, (LPVOID*)&pfile);
     if (SUCCEEDED(hr)) {
@@ -887,7 +887,7 @@
         hr = GetFilterInfo(pMoniker, &clsid, &var);
         IMoniker_Release(pMoniker);
         if (FAILED(hr)) {
-            ERR("Unable to retreive filter info (%lx)\n", hr);
+            ERR("Unable to retrieve filter info (%lx)\n", hr);
             continue;
         }
 
@@ -556,7 +556,7 @@
         }
         *pppins = CoTaskMemAlloc(sizeof(IPin*)*i);
-        /* Retreive output pins */
+        /* Retrieve output pins */
         IEnumPins_Reset(penumpins);
         i = 0;
@@ -859,7 +859,7 @@
     hr = IGraphBuilder_AddSourceFilter(iface, lpcwstrFile, string, &preader);
 
-    /* Retreive file media type */
+    /* Retrieve file media type */
     if (SUCCEEDED(hr))
         hr = IBaseFilter_QueryInterface(preader, &IID_IFileSourceFilter, (LPVOID*)&pfile);